@@ -75,8 +75,8 @@ class APIClient:
         user_config = Path().cwd() / Path('config.ini')
         default_config = Path(__file__).parent / Path('config.ini')
         config = Ini(user_config) if user_config.exists() else Ini(default_config)
-        self.host = host or config['NETWORK']['host'] or '127.0.0.1'
-        self.port = int(port) or int(config['NETWORK']['port']) or 65432
+        self.host = host or config['ARK-SERVER']['host'] or '127.0.0.1'
+        self.port = int(port) or int(config['ARK-SERVER']['port']) or 65432
         self.server_address = f"{self.host}:{self.port}"
         self.client_address = None
         self.socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
